==> armadillo-0.1.3.zip: src/jp/sourceforge/armadillo/lzh/LzhEntry.java <==
package jp.sourceforge.armadillo.lzh;

/**
 * LZH`A[JCũGgB
 */
public final class LzhEntry {

    String name;
    boolean directory;
    int headerLength;
    String method;
    long compressedSize;
    long size;
    long lastModified;
    byte type;
    byte headerLevel;
    short crc;
    char osIdentifier;

    /**
     * LzhEntry̐B
     */
    public LzhEntry() {
        this("");
    }

    /**
     * LzhEntry̐B
     * @param name name
     */
    public LzhEntry(String name) {
        this.name = name;
        this.method = "?";
        this.osIdentifier = '?';
    }

    /**
     * name̎擾B
     * @return name
     */
    public String getName() {
        return name;
    }

    /**
     * name̐ݒB
     * @param name name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * directory̎擾B
     * @return directory
     */
    public boolean isDirectory() {
        return directory;
    }

    /**
     * directory̐ݒB
     * @param directory directory
     */
    public void setDirectory(boolean directory) {
        this.directory = directory;
    }

    /**
     * headerLength̎擾B
     * @return headerLength
     */
    public int getHeaderLength() {
        return headerLength;
    }

    /**
     * headerLength̐ݒB
     * @param headerLength headerLength
     */
    public void setHeaderLength(int headerLength) {
        this.headerLength = headerLength;
    }

    /**
     * method̎擾B
     * @return method
     */
    public String getMethod() {
        return method;
    }

    /**
     * method̐ݒB
     * @param method method
     */
    public void setMethod(String method) {
        this.method = method;
    }

    /**
     * compressedSize̎擾B
     * @return compressedSize
     */
    public long getCompressedSize() {
        return compressedSize;
    }

    /**
     * compressedSize̐ݒB
     * @param compressedSize compressedSize
     */
    public void setCompressedSize(long compressedSize) {
        this.compressedSize = compressedSize;
    }

    /**
     * size̎擾B
     * @return size
     */
    public long getSize() {
        return size;
    }

    /**
     * size̐ݒB
     * @param size size
     */
    public void setSize(long size) {
        this.size = size;
    }

    /**
     * lastModified̎擾B
     * @return lastModified
     */
    public long getLastModified() {
        return lastModified;
    }

    /**
     * lastModified̐ݒB
     * @param lastModified lastModified
     */
    public void setLastModified(long lastModified) {
        this.lastModified = lastModified;
    }

    /**
     * headerLevel̎擾B
     * @return headerLevel
     */
    public byte getHeaderLevel() {
        return headerLevel;
    }

    /**
     * headerLevel̐ݒB
     * @param headerLevel headerLevel
     */
    public void setHeaderLevel(byte headerLevel) {
        this.headerLevel = headerLevel;
    }

    /**
     * crc̎擾B
     * @return crc
     */
    public short getCrc() {
        return crc;
    }

    /**
     * crc̐ݒB
     * @param crc crc
     */
    public void setCrc(short crc) {
        this.crc = crc;
    }

    /**
     * osIdentifier̎擾B
     * @return osIdentifier
     */
    public char getOsIdentifier() {
        return osIdentifier;
    }

    /**
     * osIdentifier̐ݒB
     * @param osIdentifier osIdentifier
     */
    public void setOsIdentifier(char osIdentifier) {
        this.osIdentifier = osIdentifier;
    }

}

==> armadillo-0.3.0.zip: src/jp/sourceforge/armadillo/lzh/LzhEntry.java <==
package jp.sourceforge.armadillo.lzh;

/**
 * LZH`A[JCũGgB
 */
public final class LzhEntry {

    String name;
    byte[] nameAsBytes;
    boolean directory;
    int headerLength;
    String method;
    long compressedSize;
    long size;
    int ftime;
    int timeT;
    long fileTime;
    byte type;
    byte headerLevel;
    short crc;
    char osIdentifier;
    int checksum;
    int calculatedChecksum;

    /**
     * LzhEntry̐B
     */
    public LzhEntry() {
        this("");
    }

    /**
     * LzhEntry̐B
     * @param name name
     */
    public LzhEntry(String name) {
        this.name = name;
        this.method = "?";
        this.osIdentifier = '?';
    }

    /**
     * name̎擾B
     * @return name
     */
    public String getName() {
        return name;
    }

    /**
     * name̐ݒB
     * @param name name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * GgbytezƂĎ擾B
     * Gg̃GR[fBOsv̏ꍇ͎gpȂB
     * @return bytez̃Gg
     */
    public byte[] getNameAsBytes() {
        return nameAsBytes;
    }

    /**
     * GgbytezƂĐݒ肷B
     * Gg̃GR[fBOsv̏ꍇ͎gpȂB
     * @param nameAsBytes bytez̃Gg
     */
    public void setNameAsBytes(byte[] nameAsBytes) {
        this.nameAsBytes = nameAsBytes;
    }

    /**
     * directory̎擾B
     * @return directory
     */
    public boolean isDirectory() {
        return directory;
    }

    /**
     * directory̐ݒB
     * @param directory directory
     */
    public void setDirectory(boolean directory) {
        this.directory = directory;
    }

    /**
     * method̎擾B
     * @return method
     */
    public String getMethod() {
        return method;
    }

    /**
     * method̐ݒB
     * @param method method
     */
    public void setMethod(String method) {
        this.method = method;
    }

    /**
     * compressedSize̎擾B
     * @return compressedSize
     */
    public long getCompressedSize() {
        return compressedSize;
    }

    /**
     * compressedSize̐ݒB
     * @param compressedSize compressedSize
     */
    public void setCompressedSize(long compressedSize) {
        this.compressedSize = compressedSize;
    }

    /**
     * size̎擾B
     * @return size
     */
    public long getSize() {
        return size;
    }

    /**
     * size̐ݒB
     * @param size size
     */
    public void setSize(long size) {
        this.size = size;
    }

    /**
     * ftime̎擾B
     * @return ftime
     */
    public int getFTime() {
        return ftime;
    }

    /**
     * ftime̐ݒB
     * @param ftime ftime
     */
    public void setFTime(int ftime) {
        this.ftime = ftime;
    }

    /**
     * timeT̎擾B
     * @return timeT
     */
    public int getTimeT() {
        return timeT;
    }

    /**
     * timeT̐ݒB
     * @param timeT timeT
     */
    public void setTimeT(int timeT) {
        this.timeT = timeT;
    }

    /**
     * fileTime̎擾B
     * @return fileTime
     */
    public long getFileTime() {
        return fileTime;
    }

    /**
     * fileTime̐ݒB
     * @param fileTime fileTime
     */
    public void setFileTime(long fileTime) {
        this.fileTime = fileTime;
    }

    /**
     * headerLevel̎擾B
     * @return headerLevel
     */
    public byte getHeaderLevel() {
        return headerLevel;
    }

    /**
     * headerLevel̐ݒB
     * @param headerLevel headerLevel
     */
    public void setHeaderLevel(byte headerLevel) {
        this.headerLevel = headerLevel;
    }

    /**
     * crc̎擾B
     * @return crc
     */
    public short getCrc() {
        return crc;
    }

    /**
     * crc̐ݒB
     * @param crc crc
     */
    public void setCrc(short crc) {
        this.crc = crc;
    }

    /**
     * osIdentifier̎擾B
     * @return osIdentifier
     */
    public char getOsIdentifier() {
        return osIdentifier;
    }

    /**
     * osIdentifier̐ݒB
     * @param osIdentifier osIdentifier
     */
    public void setOsIdentifier(char osIdentifier) {
        this.osIdentifier = osIdentifier;
    }

    /**
     * checksum̎擾B
     * @return checksum
     */
    public int getChecksum() {
        return checksum;
    }

    /**
     * checksum̐ݒB
     * @param checksum checksum
     */
    public void setChecksum(int checksum) {
        this.checksum = checksum;
    }

    /**
     * calculatedChecksum̎擾B
     * @return calculatedChecksum
     */
    public int getCalculatedChecksum() {
        return calculatedChecksum;
    }

    /**
     * calculatedChecksum̐ݒB
     * @param calculatedChecksum calculatedChecksum
     */
    public void setCalculatedChecksum(int calculatedChecksum) {
        this.calculatedChecksum = calculatedChecksum;
    }

}
